[Scummvm-cvs-logs] scummvm master -> 8aa6d25c7776ca0a9ee1e5ea85f6b65e10813a98

fingolfin mhorn at tu-bs.de
Thu Apr 14 14:43:34 CEST 2011


This automated email contains information about 1 new commit which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
8aa6d25c77 ALL: centerd -> centered


Commit: 8aa6d25c7776ca0a9ee1e5ea85f6b65e10813a98
    https://github.com/scummvm/scummvm/commit/8aa6d25c7776ca0a9ee1e5ea85f6b65e10813a98
Author: Max Horn (max at quendi.de)
Date: 2011-04-14T05:42:21-07:00

Commit Message:
ALL: centerd -> centered

Changed paths:
    engines/m4/mads_menus.cpp
    engines/testbed/graphics.cpp



diff --git a/engines/m4/mads_menus.cpp b/engines/m4/mads_menus.cpp
index 6d16882..4ca8154 100644
--- a/engines/m4/mads_menus.cpp
+++ b/engines/m4/mads_menus.cpp
@@ -699,7 +699,7 @@ void RexDialogView::onRefresh(RectList *rects, M4Surface *destSurface) {
 	hLine(0, width(), MADS_Y_OFFSET - 2);
 	hLine(0, width(), MADS_Y_OFFSET + MADS_SURFACE_HEIGHT + 2);
 
-	// Add in the loaded background vertically centerd
+	// Add in the loaded background vertically centered
 	_backgroundSurface->copyTo(this, 0, (height() - MADS_SURFACE_HEIGHT) / 2);
 
 	// Check whether any of the dialog text entries need to be refreshed
diff --git a/engines/testbed/graphics.cpp b/engines/testbed/graphics.cpp
index be06e58..c0ce3fe 100644
--- a/engines/testbed/graphics.cpp
+++ b/engines/testbed/graphics.cpp
@@ -606,7 +606,7 @@ TestExitStatus GFXtests::mouseMovements() {
 
 	Common::String info = "Testing Automated Mouse movements.\n"
 						"You should expect cursor hotspot(top-left corner) to automatically move from (0, 0) to (100, 100).\n"
-						"There we have a rectangle drawn, finally the cursor would lie centerd in that rectangle.";
+						"There we have a rectangle drawn, finally the cursor would lie centered in that rectangle.";
 
 	if (Testsuite::handleInteractiveInput(info, "OK", "Skip", kOptionRight)) {
 		Testsuite::logPrintf("Info! Skipping test : Mouse Movements\n");
@@ -637,7 +637,7 @@ TestExitStatus GFXtests::mouseMovements() {
 	g_system->delayMillis(1500);
 	CursorMan.showMouse(false);
 
-	if (Testsuite::handleInteractiveInput("Was the cursor centerd in the rectangle at (100, 100)?", "Yes", "No", kOptionRight)) {
+	if (Testsuite::handleInteractiveInput("Was the cursor centered in the rectangle at (100, 100)?", "Yes", "No", kOptionRight)) {
 		return kTestFailed;
 	}
 
@@ -654,7 +654,7 @@ TestExitStatus GFXtests::copyRectToScreen() {
 
 	Testsuite::clearScreen();
 	Common::String info = "Testing Blitting a Bitmap to screen.\n"
-		"You should expect to see a 20x40 yellow horizontal rectangle centerd at the screen.";
+		"You should expect to see a 20x40 yellow horizontal rectangle centered at the screen.";
 
 	if (Testsuite::handleInteractiveInput(info, "OK", "Skip", kOptionRight)) {
 		Testsuite::logPrintf("Info! Skipping test : Blitting Bitmap\n");
@@ -1113,7 +1113,7 @@ TestExitStatus GFXtests::pixelFormats() {
 
 		Graphics::Surface *screen = g_system->lockScreen();
 
 		// Draw 6 rectangles centerd at (50, 160), piled over one another
 		// each with color in colors[]
 		for (int i = 0; i < 6; i++) {
 			screen->fillRect(Common::Rect::center(160, 20 + i * 10, 100, 10), colors[i]);
@@ -1113,7 +1113,7 @@ TestExitStatus GFXtests::pixelFormats() {
 		Graphics::Surface *screen = g_system->lockScreen();
 
-		// Draw 6 rectangles centerd at (50, 160), piled over one another
+		// Draw 6 rectangles centered at (50, 160), piled over one another
 		// each with color in colors[]
 		for (int i = 0; i < 6; i++) {






More information about the Scummvm-git-logs mailing list